@@ -1,6 +1,7 @@
 import os
 import shutil
 from datetime import datetime
+from pathlib import Path
 
 import pytest
 
@@ -39,14 +40,26 @@ def db_file_path(request) -> str:
     _delete_if_exists(file_path)
 
 
+@pytest.fixture()
+def tinydb_file_path(request) -> str:
+    """Generate a unique path to a (non-existent) tinydb json file
+    The file will be removed on tear down"""
+    file_path = _build_project_dir_path_for_test(request) + ".json"
+    yield file_path
+    _delete_if_exists(file_path)
+
+
 @pytest.fixture()
 def initialized_project_dir_path(request, project_dir_path) -> str:
     """Create an initialized project and return the path to its directory
     The directory will be removed recursively on tear down"""
     entropy_dir = os.path.join(project_dir_path, _ENTROPY_DIRNAME)
     os.makedirs(entropy_dir)
+    # if used in a parametrized test, consider the parameter as a db_template
+    # and use a copy of it as the db:
     if hasattr(request, "param") and request.param is not None:
-        db_template = str(request.param)  # param input from test annotation
+        # param input from test annotation is the db_template file name:
+        db_template = os.path.join("./db_templates", str(request.param))
         db_file = os.path.join(entropy_dir, _DB_FILENAME)
         _copy_db_template(db_template, db_file, request)
     return project_dir_path
@@ -59,13 +72,17 @@ def _build_project_dir_path_for_test(request):
     project_dir_path = (
         f"tests_cache/{request.node.name}_{datetime.now():%Y-%m-%d-%H-%M-%S}"
     )
+    Path("tests_cache").mkdir(parents=True, exist_ok=True)
     return project_dir_path
 
 
-def _delete_if_exists(directory: str):
-    if os.path.isdir(directory):
-        logger.debug(f"Deleting test project directory '{directory}'")
-        shutil.rmtree(directory)
+def _delete_if_exists(path: str):
+    if os.path.isdir(path):
+        logger.debug(f"Test cleanup. Deleting directory '{path}'")
+        shutil.rmtree(path)
+    elif os.path.isfile(path):
+        logger.debug(f"Test cleanup. Deleting file '{path}'")
+        os.remove(path)
 
 
 def _copy_db_template(src, dst, request):
